module Groonga
  class Expression < Object
  end
end
